@@ -204,14 +204,14 @@ impl Display for BuildMetadata {
         let status = self.status.to_string();
         let timestamp = self.timestamp.to_string();
         writeln!(f,
-                "{id:<id_width$}{version:<version_width$}{status:<status_width$}{target_platform:<target_platform_width$}{builder_id:<id_width$}{builder_address:<address_width$}{timestamp:<timestamp_width$}{message:<message_width$}",
+                "{id:<id_width$}{version:<version_width$}{status:<status_width$}{builder_id:<id_width$}{builder_address:<address_width$}{target_platform:<target_platform_width$}{timestamp:<timestamp_width$}{message:<message_width$}",
                 id = self.id,
                 version = self.version,
                 status = status,
-                target_platform = target_platform,
-                timestamp = timestamp,
                 builder_id = self.builder_id,
                 builder_address = self.builder_address,
+                target_platform = target_platform,
+                timestamp = timestamp,
                 message = message,
                 id_width = DISPLAY_ID_WIDTH,
                 version_width = DISPLAY_VERSION_WIDTH,
@@ -231,17 +231,17 @@ impl PrintHeader for BuildMetadata {
             col0 = "Id",
             col1 = "Version",
             col2 = "Status",
-            col3 = "Target",
-            col4 = "Builder Id",
-            col5 = "Builder Address",
+            col3 = "Builder Id",
+            col4 = "Builder Address",
+            col5 = "Target Platform",
             col6 = "Timestamp",
             col7 = "Message",
             col0_width = DISPLAY_ID_WIDTH,
             col1_width = DISPLAY_VERSION_WIDTH,
             col2_width = DISPLAY_BUILD_STATUS_WIDTH,
-            col3_width = DISPLAY_BUILD_TARGET_PLATFORM_WIDTH,
-            col4_width = DISPLAY_ID_WIDTH,
-            col5_width = DISPLAY_ADDRESS_WIDTH,
+            col3_width = DISPLAY_ID_WIDTH,
+            col4_width = DISPLAY_ADDRESS_WIDTH,
+            col5_width = DISPLAY_BUILD_TARGET_PLATFORM_WIDTH,
             col6_width = DISPLAY_TIMESTAMP_WIDTH,
             col7_width = DISPLAY_MESSAGE_WIDTH,
         )
